
-- WIND curse: forces the block to move sideways -------------------------

ID_CURSE_WIND=5
ID_GLOBAL_WIND_COUNTER=0
ID_GLOBAL_WIND_BLOCK_X=1

function wind_do_curse(sent)
    if sent==0 then
        u61_send_curse(ID_CURSE_WIND)
    else
        u61_register_curse(ID_CURSE_WIND,30000,0)
        wind_reset_globals()
    end
end

function wind_time_callback()
    if u61_get_curse_age(ID_CURSE_WIND)>=0 then
        if u61_get_global(ID_GLOBAL_WIND_BLOCK_X)==u61_get_block_x() then
            if u61_get_time()-u61_get_global(ID_GLOBAL_WIND_COUNTER)>=100 then
                u61_set_block_x(u61_get_block_x()-1)
                wind_reset_globals()
            end
        else
            wind_reset_globals()
        end
    end
end

function wind_reset_globals()
    u61_set_global(ID_GLOBAL_WIND_COUNTER,u61_get_time())
    u61_set_global(ID_GLOBAL_WIND_BLOCK_X,u61_get_block_x())
end




